@@ -52,7 +52,7 @@ class File(object):
 
     @classmethod
     def isfile(cls, filepath):
-        return isfile(filepath)
+        return os.path.isfile(filepath)
 
     @classmethod
     def listdir(cls, filepath):
@@ -69,6 +69,17 @@ class File(object):
     @classmethod
     def mkdirs(cls, filepath):
         return mkdirs(filepath)
+    
+    @classmethod
+    def getdir(cls, filepath):
+        if 'gs://' not in filepath:
+            return os.path.abspath(os.path.dirname(filepath))
+        fname = filepath.split('/')[-1]
+        return filepath.replace(fname, '').strip()
+    
+    @classmethod
+    def isdir(cls, filepath):
+        return isdir(filepath)
 
     @classmethod
     def glob(cls, filepath):
@@ -92,7 +103,7 @@ class File(object):
     
     @classmethod
     def bcopy(cls, src, directory, overwrite=True):
-        if not isdir(directory):
+        if not exists(directory):
             mkdirs(directory)
         dest = os.path.join(directory, os.path.basename(src))
         if not exists(dest) or overwrite:
@@ -448,6 +459,13 @@ class File(object):
         filenames = File.fsorter(filenames)
         for fname in filenames:
             yield File.jg(fname, handle_errors)
+    
+    @classmethod
+    def jsong(cls, filenames, handle_errors=True):
+        filenames = File.fsorter(filenames)
+        for fname in filenames:
+            yield File.jsonload(fname, handle_errors)
+    
 
     def __call__(self, filename, mode='r'):
         return self.open(filename, mode)
